@@ -53,23 +53,18 @@ def dict2ring(data: dict, unit: str = "", second_unit: str = "", key: str = "cou
     total = 0
     for name, value in data.items():
         total += get_value_by_key(value, key)
+    if flag:
+        weight = 100
+    else:
+        weight = 1
     result = {
         "title": title,
         "data": [{"name": name,
                   "unit": unit,
-                  "value": (money_format(get_value_by_key(value, key) / total * 100)) if total > 0 else 0,
+                  "value": (money_format(get_value_by_key(value, key) / total * weight)) if total > 0 else 0,
                   "second_unit": second_unit,
                   "second_value": get_value_by_key(value, key)} for name, value in data.items()]
     }
-    for name, value in data.items():
-        value = (money_format(get_value_by_key(value, key) / total)) if total > 0 else 0
-        if flag:
-            value = value * 100
-        result["data"].append({"name": name,
-                               "unit": unit,
-                               "value": value,
-                               "second_unit": second_unit,
-                               "second_value": get_value_by_key(value, key)})
     return result
 
 
