@@ -10,11 +10,9 @@ import types
 import uuid
 from contextlib import contextmanager
 from datetime import datetime
-from decimal import Decimal
 from typing import Optional, Awaitable, Any
 from urllib.parse import unquote
 
-from bson import ObjectId
 from tornado import httputil
 from tornado.escape import utf8
 from tornado.ioloop import IOLoop
@@ -371,15 +369,16 @@ class BaseHandler(RequestHandler):
 
 class JSONEncoder(json.JSONEncoder):
     def default(self, o):
-        if isinstance(o, ObjectId):
+        object_class_name = o.__class__.__name__
+        if object_class_name == "ObjectId":
             return str(o)
-        elif isinstance(o, datetime):
+        elif object_class_name == "datetime":
             return str(o)
-        elif isinstance(o, bytes):
+        elif object_class_name == "bytes":
             return str(o, encoding="utf-8")
-        elif isinstance(o, set):
+        elif object_class_name == "set":
             return list(o)
-        elif isinstance(o, Decimal):
+        elif object_class_name == "Decimal":
             return str(o)
         return json.JSONEncoder.default(self, o)
 
